@@ -19,7 +19,7 @@ from emq.message.ttypes import SendMessageRequest, ReceiveMessageRequest, Change
 from emq.queue.ttypes import CreateQueueRequest, ListQueueRequest, SetQueueAttributesRequest, SetPermissionRequest, \
   RevokePermissionRequest, QueryPermissionForIdRequest, SetQueueQuotaRequest, QueueQuota, CreateTagRequest, \
   DeleteTagRequest, GetTagInfoRequest, ListTagRequest, SetQueueRedrivePolicyRequest, RemoveQueueRedrivePolicyRequest, \
-  CopyQueueRequest, QueryPrivilegedQueueRequest, DeleteQueueRequest
+  ListDeadLetterSourceQueuesRequest
 from emq.statistics.ttypes import SetUserQuotaRequest, GetUserQuotaRequest, GetUserUsedQuotaRequest, SetUserInfoRequest, \
   GetUserInfoRequest
 
@@ -32,12 +32,11 @@ class RequestChecker(object):
     if len(self.__args) > 1:
       errMsg = "Unknown request"
       raise GalaxyEmqServiceException(errMsg=errMsg)
-    elif len(self.__args) == 1:
+    else:
       self.check_request_params(self.__args[0])
 
   def check_request_params(self, request):
-    if isinstance(request, ListQueueRequest) or \
-        isinstance(request, QueryPrivilegedQueueRequest):
+    if isinstance(request, ListQueueRequest):
       self.validate_queue_prefix(request.queueNamePrefix)
     elif isinstance(request, CreateQueueRequest):
       self.validate_queue_name(request.queueName, True, True)
@@ -54,6 +53,8 @@ class RequestChecker(object):
       self.validate_redrivePolcy(request.redrivePolicy)
     elif isinstance(request, RemoveQueueRedrivePolicyRequest):
       self.validate_queue_name(request.queueName)
+    elif isinstance(request, ListDeadLetterSourceQueuesRequest):
+      self.validate_queue_name(request.dlqName)
     elif isinstance(request, SetPermissionRequest):
       self.validate_queue_name(request.queueName)
       self.validate_not_none(request.developerId, "developerId")
@@ -87,7 +88,7 @@ class RequestChecker(object):
       self.validate_queue_name(request.queueName)
       self.validate_not_none(request.messageBody, "messageBody")
       if request.messageAttributes is not None:
-        for attribute in request.messageAttributes.values():
+        for attribute in list(request.messageAttributes.values()):
           self.check_message_attribute(attribute, False)
       if request.delaySeconds is not None:
         self.validate_delaySeconds(request.delaySeconds)
@@ -165,13 +166,6 @@ class RequestChecker(object):
           or isinstance(request, GetUserUsedQuotaRequest) or isinstance(request, SetUserInfoRequest)
           or isinstance(request, GetUserInfoRequest)):
       pass
-    elif isinstance(request, DeleteQueueRequest):
-      self.validate_queue_name(request.queueName)
-    elif isinstance(request, CopyQueueRequest):
-      queueMeta = request.queueMeta
-      self.validate_queue_name(queueMeta.queueName)
-    elif isinstance(request, basestring):
-      self.validate_queue_name(request)
     else:
       self.validate_queue_name(request.queueName)
 
@@ -182,7 +176,7 @@ class RequestChecker(object):
     if send_entry.invisibilitySeconds is not None:
       self.validate_invisibilitySeconds(send_entry.invisibilitySeconds)
     if send_entry.messageAttributes is not None:
-      for attribute in send_entry.messageAttributes.values():
+      for attribute in list(send_entry.messageAttributes.values()):
         self.check_message_attribute(attribute, False)
 
   def check_message_attribute(self, attribute, allow_empty):
@@ -206,7 +200,7 @@ class RequestChecker(object):
     self.validate_changeInvisibilitySeconds(change_entry.invisibilitySeconds)
 
   def check_list_duplicate(self, l, name):
-    if len(l) != len({}.fromkeys(l).keys()):
+    if len(l) != len(list({}.fromkeys(l).keys())):
       raise GalaxyEmqServiceException(errMsg="Bad request, %s shouldn't be duplicate." % name)
 
   def validate_queue_name(self, queue_name, allow_slash=True, is_prefix=False, param_name="queue name"):
@@ -229,13 +223,13 @@ class RequestChecker(object):
       return True
     if c in string.punctuation:
       return True
-    if category(unicode(c)) == 'Sc':
+    if category(str(c)) == 'Sc':
       return True
-    if category(unicode(c)) == 'Mn':
+    if category(str(c)) == 'Mn':
       return True
-    if category(unicode(c)) == 'N1':
+    if category(str(c)) == 'N1':
       return True
-    if category(unicode(c)) == 'Mc':
+    if category(str(c)) == 'Mc':
       return False
     return False
 
@@ -263,7 +257,7 @@ class RequestChecker(object):
       self.validate_user_attribute(queue_attribute.userAttributes)
 
   def validate_user_attribute(self, attribute):
-    for key, value in attribute.items():
+    for key, value in list(attribute.items()):
       self.validate_not_empty(key, "user attribute name")
       self.validate_not_empty(value, "user attribute value for \"" + key + "\"")
 
